==> haskell-bytestring-handle-0.1.0.6-199-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-6Dy2Qns2gyUK7czMKLQTA8
key:                  bytestring-handle-0.1.0.6-6Dy2Qns2gyUK7czMKLQTA8
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  e6ef7c2cf9e8a54a4ab4f12e3bb3e2c4
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-handle
hs-libraries:         HSbytestring-handle-0.1.0.6-6Dy2Qns2gyUK7czMKLQTA8
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-handle-0.1.0.6-200-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-handle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bytestring-handle
version:              0.1.0.6
visibility:           public
id:                   bytestring-handle-0.1.0.6-7LEIORmjUyqASaYVBvoJwk
key:                  bytestring-handle-0.1.0.6-7LEIORmjUyqASaYVBvoJwk
license:              BSD-3-Clause
maintainer:           Ganesh Sittampalam <ganesh@earth.li>
author:               Ganesh Sittampalam
homepage:             http://hub.darcs.net/ganesh/bytestring-handle
synopsis:             ByteString-backed Handles
category:             System
abi:                  209086a8aef808c4c69adedb0a3ec2af
exposed:              True
exposed-modules:      Data.ByteString.Handle
hidden-modules:
    Data.ByteString.Handle.Read Data.ByteString.Handle.Write

import-dirs:          /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/bytestring-handle-0.1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-handle
hs-libraries:         HSbytestring-handle-0.1.0.6-7LEIORmjUyqASaYVBvoJwk
depends:              base-4.17.2.1 bytestring-0.11.5.3
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-handle/html/bytestring-handle.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-handle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
